@@ -15,34 +15,25 @@
 #-------------------------------------------------------------------------------
 package Bricklayer::Templater::Parser;
 
-=head1 NAME
-
-    Bricklayer::Templater::Parser - The parsing engine for Bricklayer::Templater
-
-=head1 Methods
-
-=cut
-
+require Exporter;
 use strict;
 use Carp;
 
+our @ISA = qw(Exporter);
+our @EXPORT = qw(parse_text parse_attributes);
+
 # Global Variables
 my $DefaultTagID = 'BK';
 
+
 # Package Methods
 sub parse_text {
 	# Function wide variables
 	my $textblock = shift; 	#this variable contains the block of text to be parsed.
-	my $tagID = shift or croak('Must pass in tagid');		# this variable contains the ID of the tag it is optional
-    my $startbracket = shift or croak('Must pass in startbracket');
-	my $endbracket   = shift or croak('Must pass in endbracket');
-    my $TagStartText = $startbracket.$tagID; # Start tag prefix (it gets passed in)
-    my $TagEndText = $startbracket.'/'.$tagID; # End tag prefix (it also gets passed in)
-	#carp("startbracket: $startbracket");
-	#carp("endbracket: $endbracket");
-	#carp("TagStartText: $TagStartText");
-	#carp("TagEndText: $TagEndText");
-    my @tokens = ();				#this variable will contain the tokenized text.
+	my $tagID = shift || $DefaultTagID;		# this variable contains the ID of the tag it is optional
+	my $TagStartText = "<$tagID"; # Start tag prefix (it gets passed in)
+	my $TagEndText = "</$tagID"; # End tag prefix (it also gets passed in)
+	my @tokens = ();				#this variable will contain the tokenized text.
 	 
 	# loop through the string tokenizing as you go.  Since you are actually removing
 	#  the pieces of text as you go, when you are finished, the string should be empty.
@@ -59,13 +50,12 @@ sub parse_text {
 
 		# check to see if the first part of the string is not a tag, ie doesn't start with the Start Tag Prefix..
 		if (substr($textblock, 0, length($TagStartText)) ne $TagStartText) {
-	        #carp("In a text block");	
+		
 			# find the begining of the tag.
 			$endpos = index($textblock, $TagStartText);
 			# populate the text block
 			if ($endpos == -1) {
-				#carp("No more text to process");
-                # if there are no more template tags, put the remaining text into the block 
+				# if there are no more template tags, put the remaining text into the block 
 				$block = substr($textblock, 0);
 				#remove the text block from $textblock.
 				$textblock = "";
@@ -81,7 +71,7 @@ sub parse_text {
 				type => "text", 
 				tagname => "text_block", 
 				block => $block,
-		        tagid => $tagID
+			        tagid => $tagID
 			);
 
 			#put the token at the bottom of the stack.
@@ -92,22 +82,22 @@ sub parse_text {
 			my $tag;
 			
 			# get the tag from the string.
-			$tag = substr($textblock,0,index($textblock, $endbracket) +1);
+			$tag = substr($textblock,0,index($textblock, '>') +1);
 			
 			# This is where we determine if the tag is a block or a single tag.
 			#  We do this by looking for the forward slash, if it doesn't find one
 			#  then it means the tag is a block.
-			if (index($tag, "/$endbracket") == -1) { 
+			if (index($tag, '/>') == -1) { 
 				
 				# Get the tag name.
-				$tagname = substr($tag, length($TagStartText), index($tag, $endbracket)-length($TagStartText));
+				$tagname = substr($tag, length($TagStartText), index($tag, '>')-length($TagStartText));
 				if (index($tagname, ' ') != -1) {
 					$tagname = substr($tagname, 0, index($tagname, ' '));
 				}
 							
 				# Get the tag block.
 				# But first remove the opening tag from $textblock.
-				$textblock = substr($textblock, index($textblock, $endbracket)+1);
+				$textblock = substr($textblock, index($textblock, '>')+1);
 				
 			
 				# before going on, you must check for nested tags identical to the current tag.
@@ -117,52 +107,48 @@ sub parse_text {
 				my $close_len = length($close_tag);
 				my $ignore = 0;
 				my $found_end = 0;
-                #is there an open tag in our text block still?
 				my $idx_open_tag = index($textblock,$open_tag);
-                #is there a close tag in our text block?
 				my $idx_close_tag = index($textblock,$close_tag);
 				
 				while (not $found_end) {
   					
-				    if ($idx_open_tag == -1 or $idx_open_tag > $idx_close_tag) {
-						# there is not open tag or there is an open tag before the close tag
-                        # This is a possible end tag, check to see if it is what 
+				if ($idx_open_tag == -1 or $idx_open_tag > $idx_close_tag) {
+						# This is a possible end tag, check to see if it is what 
 						# we are looking for
 						if ($ignore > 0 ) {
 							# this is not the end tag you are looking for...
 							$ignore--;
-                            # find the index of the next close tag after this one;
 							$idx_close_tag = index($textblock, $close_tag, $idx_close_tag+$close_len)
 						
 						} else {
 	  						# This is the end tag you are looking for.
 							$found_end = 1;
 						}
-  					} else {# there is another open tag before our first close tag
+  					} else {
 						# this is a nested open tag, it needs to be checked 
 						# to see if it is self closing.
   						my $nested_tag = 
 							substr($textblock,$idx_open_tag,
-								index($textblock, $endbracket, $idx_open_tag)-$idx_open_tag+1);
-  						if (index($nested_tag, "/$endbracket") == -1) { 
+								index($textblock, '>', $idx_open_tag)-$idx_open_tag+1);
+  						if (index($nested_tag, '/>') == -1) { 
 							# this is a nested block tag
-							$ignore++;
+							$ignore += 1;
   						}
 						# find the next open tag.
 						$idx_open_tag = index($textblock, $open_tag, $idx_open_tag+$open_len)
   					}
 				}				
-				# grab our block from the text block start to the closing tags index
+				
 				$block = substr($textblock, 0, $idx_close_tag);				
 
 				# and remove the block of text from $textblock.
 				$textblock = substr($textblock, $idx_close_tag);
 				# remove the closing tag from $textblock.
-				$textblock = substr($textblock, index($textblock, $endbracket)+1);
+				$textblock = substr($textblock, index($textblock, '>')+1);
 				
 				# get the attributes.
 				$tag = substr($tag,length($TagStartText));
-				$tag = substr($tag, 0, index($tag, $endbracket));
+				$tag = substr($tag, 0, index($tag, '>'));
 
 				%attributes = parse_attributes($tag);
 		
@@ -180,17 +166,17 @@ sub parse_text {
 				# this parses a single tag out.
 
 				# Get the tag name.
-				$tagname = substr($tag, length($TagStartText), index($tag, $endbracket)-(length($TagStartText)+1));
+				$tagname = substr($tag, length($TagStartText), index($tag, '>')-(length($TagStartText)+1));
 				if (index($tagname, ' ') != -1) {
 					$tagname = substr($tagname, 0, index($tagname, ' '));
 				}
 				
 				# remove the tag from $textblock.
-				$textblock = substr($textblock, index($textblock, $endbracket)+1);
+				$textblock = substr($textblock, index($textblock, '>')+1);
 			
 				# get the attributes.
 				$tag = substr($tag,length($TagStartText));
-				$tag = substr($tag, 0, index($tag, $endbracket));
+				$tag = substr($tag, 0, index($tag, '/>'));
 				%attributes = parse_attributes($tag);
 		
 				# populate the token
@@ -261,17 +247,17 @@ return 1;
 
 =head1 NAME
 
-Bricklayer::Templater::Parser - A generic parsing module.
+Template::Parser - A generic parsing module.
 
 =head1 SYNOPSIS
 
-use Bricklayer::Templater::Parser;
+use Template::Parser;
 
 my $template_text;
 my $start_tag_prefix;
 my $end_tag_prefix;
 
-my @tokens = Template::Parser::parse_text($template_text,$start_tag_prefix,$end_tag_prefix);
+my @tokens = Parser::parse_text($template_text,$start_tag_prefix,$end_tag_prefix);
 
 =head1 REQUIRES
 
@@ -289,7 +275,7 @@ the array.
 
 =head1 METHODS
 
-=head2 parse_text()
+=item parse_text()
 
 The parse_text() function takes the template text, a start tag prefix, and an end
 tag prefix, parses the appropriate tags and returns a token tree in the form of an
@@ -297,35 +283,35 @@ array of hashes, each hash with a variable number of elements, depending on its
 
 For Example:
  
-    %text_token = (
-                    type => "text", 
-                    block => $block,	
-                );
-    
-    %block_tag_token = (
-                    type => "block_tag", 
-                    tagname => $tagname,
-                    block => $block,
-                    attributes => \%attributes,
-                );	
-    
-    %tag_token = (
-                    type => "tag", 
-                    tagname => $tagname,
-                    attributes => \%attributes,
-                );
+%text_token = (
+				type => "text", 
+				block => $block,	
+			);
+
+%block_tag_token = (
+				type => "block_tag", 
+				tagname => $tagname,
+				block => $block,
+				attributes => \%attributes,
+			);	
+
+%tag_token = (
+				type => "tag", 
+				tagname => $tagname,
+				attributes => \%attributes,
+			);
 
 The attributes value is a reference to an attributes hash in the form of:
 
-    %attributes = (
-    				"attribute_name" => "attribute_value",
-    			);
-    
-Further Notes: The token tree returned by parse_text is not recursive, thus the 
-tags inside a tag_block will not be processed, and you will need to call the
-parse_text() function again when dealing with those tags.
+%attributes = (
+				"attribute_name" => "attribute_value",
+			);
+
+Further Notes: The token tree returned by parse_text is not iterative, thus the 
+  tags inside a tag_block will not be processed, and you will need to call the 
+	parse_text() function again when dealing with those tags.
 	
-To build a complete tree, call the parse_text() function iteratively like so:
+	To build a complete tree, call the parse_text() function iteratively like so:
 	
 	sub parse {
 		my $template_text = shift;
@@ -346,17 +332,11 @@ To build a complete tree, call the parse_text() function iteratively like so:
     return @token_tree;
 	}
 
-=head2 parse_attributes 
-
-parses the tag attributes
-
-=head2 mytrim
-
-trims whitespace for us
-
 =head1 AUTHOR
 
 (c) 2004 Jason Wall, <jason@walljm.com>, www.walljm.com
-(c) 2004 Jeremy Wall, <jeremy@marzhillstudios.com>, jeremy.marzhillstudios.com
 
 =cut
+
+
+
