@@ -11,50 +11,34 @@
 #
 #-------------------------------------------------------------------------------
 package Bricklayer::Templater::Sequencer;
-
+require Exporter;
 use strict;
-use Carp;
 
 use Bricklayer::Templater::Parser;
 
-=head1 NAME
-
-Bricklayer::Templater::Sequencer - Internal Module used by L<Bricklayer::Templater>;
-
-=head1 Description
-
-Handles parsing the template and replacing the tags with returned text for Bricklayer::Templater
-
-=head1 METHODS
-
-=head2 new_sequencer
-
-Creates a new sequencer object. 
-
-=cut
-
 my %handlerCache;
 
+our @ISA = qw(Exporter);
+our @EXPORT = qw(new_sequencer return_parsed);
+
 sub new_sequencer {
     my $Proto = shift;
-    my $TemplateText = shift or confess("No template specified");
+    my $TemplateText = shift or die "No template specified";
     my $tagID = shift;
-    my $start = shift;
-    my $end   =shift;
-    
     my $Class = ref($Proto) || $Proto;
-    my @TokenList = Bricklayer::Templater::Parser::parse_text($TemplateText, $tagID, $start, $end);
+    my @TokenList = parse($TemplateText, $tagID);
     #die "this many tokens found ".scalar(@TokenList);
     return bless(\@TokenList, $Class); 
     
 }
 
-=head2 return_parsed
-
-returns a string with the replacement text for a parsed token
-
-=cut
-
+sub parse {
+    my $TemplateText = shift;
+    my $tagID = shift;
+    #die $tagID;
+    my @Tokens =  Bricklayer::Templater::Parser::parse_text($TemplateText, $tagID);
+    return @Tokens;
+}
 
 # returns a string with the replacement text for the parsed token
 sub return_parsed($$$$) {
@@ -67,12 +51,6 @@ sub return_parsed($$$$) {
     return; 
 }
 
-=head2 parse_tokens
-
-actually runs through the list of tokens and loades the handler or retrieves it from the handler cache to run.
-
-=cut
-
 sub parse_tokens($$$$) {
     my $TokenList = shift;
     my $App = shift;
@@ -87,20 +65,24 @@ sub parse_tokens($$$$) {
         # Seperate handlers with :: to denote directories
         # in the handler directory.
         my $handler;
-        my $tagname = 'Bricklayer::Templater::Handler::'.$Token->{tagname};
+        my $tagname = $Token->{tagname};
         my $Seperator = "/";
-        my $SymbolicRef = $tagname;
-#        $tagname =~ s/::/$Seperator/g;
+        $tagname =~ s/::/$Seperator/g;
+        my $SymbolicRefLoader = $handler_loc."/handler/" . $tagname . ".pm";
+        my $DefaultRefLoader = "Bricklayer/Templater/default/" . $tagname . ".pm";
+        my $SymbolicRef = $Token->{tagname};
         if (exists($handlerCache{$Token->{tagname}})) {
         	$handler = $handlerCache{$Token->{tagname}}->load($Token, $App);
             $handler->run_handler($Parameters);
             
         } else {
-            eval "use $tagname";
-        	if (!$@) {	            
+        	if (-r $SymbolicRefLoader) {
+	            require $SymbolicRefLoader;
+	            $handler = $SymbolicRef->load($Token, $App);
+	        } elsif (require $DefaultRefLoader) {	            
 	            $handler = $SymbolicRef->load($Token, $App);
 	        } else {
-	            carp("grrr no such handler: $Token->{tagname} at $tagname.pm");
+	            $App->errors("grrr no such handler: $Token->{tagname} at $SymbolicRefLoader", "log");
 	            next;
 	        }
 	        $handlerCache{$Token->{tagname}} = $SymbolicRef;
@@ -110,10 +92,4 @@ sub parse_tokens($$$$) {
     return;
 }
 
-=head1 SEE ALSO
-
-L<Bricklayer::Templater>
-
-=cut
-
 return 1;
